==> qtjambi-sensors-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiSensors/QSensorBackend_shell.h <==
#ifndef QSENSORBACKEND_SHELL_H
#define QSENSORBACKEND_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSensors/qsensorbackend.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSensors/qsensor.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QSensorBackend_shell : public QSensorBackend, public QtJambiShellInterface
{
public:
    QSensorBackend_shell(QSensor* sensor0, QObject* parent1 = nullptr);
    ~QSensorBackend_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isFeatureSupported(QSensor::Feature feature0) const override;
    void start() override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSensorBackend_access : public QSensorBackend
{
    jboolean __qt_isFeatureSupported_QSensor_Feature_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint feature0) const;
    void __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSENSORBACKEND_SHELL_H

==> qtjambi-sensors-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiSensors/QSensorBackend_shell.h <==
#ifndef QSENSORBACKEND_SHELL_H
#define QSENSORBACKEND_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSensors/qsensorbackend.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSensors/qsensor.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QSensorBackend_shell : public QSensorBackend, public QtJambiShellInterface
{
public:
    QSensorBackend_shell(QSensor* sensor0, QObject* parent1 = nullptr);
    ~QSensorBackend_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isFeatureSupported(QSensor::Feature feature0) const override;
    void start() override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSensorBackend_access : public QSensorBackend
{
    jboolean __qt_isFeatureSupported_QSensor_Feature_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint feature0) const;
    void __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSENSORBACKEND_SHELL_H
